@@ -2,6 +2,8 @@ from enum import IntEnum
 
 
 class UserEventType(IntEnum):
+    UNDEFINED_EVENT = -1
+
     REPLACE_MESSAGE_FLAGS = 1
     INSTALL_MESSAGE_FLAGS = 2
     RESET_MESSAGE_FLAGS = 3
@@ -18,6 +20,9 @@ class UserEventType(IntEnum):
     DELETE_MESSAGES = 13
     CHAT_RESTORE = 14
 
+    MESSAGE_CHANGE = 18
+    CLEAR_MESSAGE_CACHE = 19
+
     CHANGE_MAJOR_ID = 20
     CHANGE_MINOR_ID = 21
 
@@ -28,7 +33,13 @@ class UserEventType(IntEnum):
     USER_TYPING_STATE = 62
     USERS_TYPING_STATE = 63
     VOICE_MESSAGE_STATES = 64
+    PHOTO_UPLOAD_STATE = 65
+    VIDEO_UPLOAD_STATE = 66
+    FILE_UPLOAD_STATE = 67
 
     CALL = 70
     COUNTER = 80
+    USER_INVISIBLE_CHANGE = 81
     NOTIFICATIONS_SETTINGS_CHANGED = 114
+    CHAT_CALL = 115
+    CALLBACK_BUTTON_REPLY = 119
