@@ -10,7 +10,7 @@ class StorageCategory(BaseCategory):
         keys: typing.Optional[typing.List[str]] = None,
         user_id: typing.Optional[int] = None,
         **kwargs
-    ) -> storage.GetResponseModel:
+    ) -> typing.List[storage.StorageValue]:
         """Returns a value of variable with the name set by key parameter.
         :param key:
         :param keys:
@@ -28,7 +28,7 @@ class StorageCategory(BaseCategory):
         offset: typing.Optional[int] = None,
         count: typing.Optional[int] = None,
         **kwargs
-    ) -> storage.GetKeysResponseModel:
+    ) -> typing.List[str]:
         """Returns the names of all variables.
         :param user_id: user id, whose variables names are returned if they were requested with a server method.
         :param offset:
@@ -46,7 +46,7 @@ class StorageCategory(BaseCategory):
         value: typing.Optional[str] = None,
         user_id: typing.Optional[int] = None,
         **kwargs
-    ) -> base.OkResponseModel:
+    ) -> int:
         """Saves a value of variable with the name set by 'key' parameter.
         :param key:
         :param value:
